<?php

namespace Loans\Loan\Http\Controllers;

use App\Http\Controllers\AdminController as AdminController;
use Former;
use Loans\Loan\Http\Requests\LoansAdminRequest;
use Loans\Loan\Interfaces\LoansRepositoryInterface;
use Response;

/**
 * Admin controller class.
 */
class LoansAdminController extends AdminController
{
    /**
     * Initialize loans controller.
     *
     * @param type LoansRepositoryInterface $loans
     *
     * @return type
     */
    public function __construct(LoansRepositoryInterface $loans)
    {
        $this->model = $loans;
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(LoansAdminRequest $request)
    {
        if ($request->wantsJson()) {
            $array = $this->model->json();
            foreach ($array as $key => $row) {
                $array[$key] = array_only($row, config('loan.loans.listfields'));
            }

            return ['data' => $array];
        }

        $this->theme->prependTitle(trans('loan::loans.names').' :: ');

        return $this->theme->of('loan::admin.loans.index')->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(LoansAdminRequest $request, $id)
    {
        $loans = $this->model->find($id);

        if (empty($loans)) {
            if ($request->wantsJson()) {
                return [];
            }

            return view('loan::admin.loans.new');
        }

        if ($request->wantsJson()) {
            return $loans;
        }

        Former::populate($loans);

        return view('loan::admin.loans.show', compact('loans'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LoansAdminRequest $request)
    {
        $loans = $this->model->findOrNew(0);
        Former::populate($loans);

        return view('loan::admin.loans.create', compact('loans'));
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LoansAdminRequest $request)
    {
        try {
            $attributes = $request->all();
            $loans = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('loan::loans.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(LoansAdminRequest $request, $id)
    {
        $loans = $this->model->find($id);

        Former::populate($loans);

        return view('loan::admin.loans.edit', compact('loans'));
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(LoansAdminRequest $request, $id)
    {
        try {
            $attributes = $request->all();
            $loans = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('loan::loans.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(LoansAdminRequest $request, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('loan::loans.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
