<?php

namespace Loans\Loan\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Loans\Loan\Http\Requests\LoansUserRequest;
use Loans\Loan\Interfaces\LoansRepositoryInterface;
use Response;
use User;

class LoansUserController extends UserController
{
    /**
     * Initialize loans controller.
     *
     * @param type LoansRepositoryInterface $loans
     *
     * @return type
     */
    public function __construct(LoansRepositoryInterface $loans)
    {
        $this->model = $loans;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(LoansUserRequest $request)
    {
        $loans = $this->model->all();

        $this->theme->prependTitle(trans('loan::loans.names').' :: ');

        return $this->theme->of('loan::user.loans.index', compact('loans'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(LoansUserRequest $request, $role, $id)
    {
        $loans = $this->model->find($id);

        return $this->theme->of('loan::user.loans.show', compact('loans'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LoansUserRequest $request)
    {
        $loans = $this->model->findOrNew(0);

        Former::populate($loans);

        return $this->theme->of('loan::user.loans.create', compact('loans'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LoansUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $loans = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('loan::loans.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(LoansUserRequest $request, $role, $id)
    {
        $loans = $this->model->find($id);

        Former::populate($loans);

        return $this->theme->of('loan::user.loans.edit', compact('loans'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(LoansUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $loans = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('loan::loans.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(LoansUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('loan::loans.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
