<?php

namespace Loans\Loan\Http\Requests;

use App\Http\Requests\Request;
use User;

class LoansAdminRequest extends Request
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize(\Illuminate\Http\Request $request)
    {
        // Determine if the user is authorized to create an entry,
        if ($request->isMethod('POST') || $request->is('*/create')) {
            return User::can('loan.loans.create');
        }

        // Determine if the user is authorized to update an entry,
        if ($request->isMethod('PUT') || $request->isMethod('PATCH') || $request->is('*/edit')) {
            return User::can('loan.loans.edit');
        }

        // Determine if the user is authorized to delete an entry,
        if ($request->isMethod('DELETE')) {
            return User::can('loan.loans.delete');
        }

        // Determine if the user is authorized to view the module.
        return User::can('loan.loans.view');
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array
     */
    public function rules(\Illuminate\Http\Request $request)
    {
        // validation rule for create request.
        if ($request->isMethod('POST')) {
            return [
                'name'                => 'required',
                'loan_amount'         => 'required',
                'first_paid_date'     => 'required',
                'payment_period'      => 'required',
                'client_id'           => 'required',
                'user_id'             => 'required',
            ];
        }

        // Validation rule for update request.
        if ($request->isMethod('PUT') || $request->isMethod('PATCH')) {
            return [
                'name'                => 'required',
                'loan_amount'         => 'required',
                'first_paid_date'     => 'required',
                'payment_period'      => 'required',
                'client_id'           => 'required',
                'user_id'             => 'required',
            ];
        }

        // Default validation rule.
        return [

        ];
    }
}
